@@ -1,8 +1,8 @@
-from operations_with_objects.operations_with_objects import OperationsWithObjects
-from operations_with_objects.system_object import SystemObject
-from quick_resto_api import QuickRestoApi
-from quick_resto_objects.modules.warehouse.dish import Dish
-from quick_resto_objects.modules.warehouse.dish_category import DishCategory
+from quick_resto_API.operations_with_objects.operations_with_objects import OperationsWithObjects
+from quick_resto_API.operations_with_objects.system_object import SystemObject
+from quick_resto_API.quick_resto_api import QuickRestoApi
+from quick_resto_API.quick_resto_objects.modules.warehouse.dish import Dish
+from quick_resto_API.quick_resto_objects.modules.warehouse.dish_category import DishCategory
 
 
 class DishOperations(SystemObject):
