@@ -1,8 +1,8 @@
-from operations_with_objects.operations_with_objects import OperationsWithObjects
-from operations_with_objects.system_object import SystemObject
-from quick_resto_objects.modules.warehouse.modifier import Modifier
-from quick_resto_objects.modules.warehouse.modifier_group import ModifierGroup
-from quick_resto_api import QuickRestoApi
+from quick_resto_API.operations_with_objects.operations_with_objects import OperationsWithObjects
+from quick_resto_API.operations_with_objects.system_object import SystemObject
+from quick_resto_API.quick_resto_objects.modules.warehouse.modifier import Modifier
+from quick_resto_API.quick_resto_objects.modules.warehouse.modifier_group import ModifierGroup
+from quick_resto_API.quick_resto_api import QuickRestoApi
 
 class ModifierOperations(SystemObject):
     def __init__(self, api: QuickRestoApi):
