@@ -33,7 +33,7 @@ class Employee(QuickRestoObject):
     def __init__(self, systemEmployee: str = None, user: dict = None, firstName: str = None, lastName: str = None,
                  blocked: bool = None,
                  shortName: str = None, fullName: str = None, **kwargs):
-        class_name = ""
+        class_name = "ru.edgex.quickresto.modules.personnel.employee.Employee"
         super().__init__(class_name=class_name, **kwargs)
 
         self._system_employee: str = systemEmployee
